@@ -115,8 +115,10 @@ class LineClient(LineAPI):
 
         return None
 
-    def getContactOrGroupById(self, id):
-        return self.getContactById(id) or self.getGroupById(id)
+    def getContactOrRoomOrGroupById(self, id):
+        return self.getContactById(id)\
+                or self.getRoomById(id)\
+                or self.getGroupById(id)
 
     def refreshGroups(self):
         """Refresh groups of LineClient"""
@@ -299,6 +301,17 @@ class LineClient(LineAPI):
 
                 return None
 
+    def getRoomById(self, id):
+        """Get a room by id
+        
+        :param id: id of a room
+        """
+        for room in self.rooms:
+            if room.id == id:
+                return room
+
+        return None
+
     def inviteIntoRoom(self, room, contacts=[]):
         """Invite contacts into room
         
@@ -378,16 +391,32 @@ class LineClient(LineAPI):
                 elif operation.type == OT.SEND_MESSAGE:
                     pass
                 elif operation.type == OT.RECEIVE_MESSAGE:
-                    message = LineMessage(self, operation.message)
-                    group_or_contact = self.getContactOrGroupById(message.to)
+                    message    = LineMessage(self, operation.message)
+                    raw_sender = operation.message._from
+                    sender     = self.getContactOrRoomOrGroupById(raw_sender)
 
-                    yield (group_or_contact, message)
+                    if sender is None:
+                        self.refreshGroups()
+                        self.refreshContacts()
+                        self.refreshActiveRooms()
+
+                        sender = self.getContactOrRoomOrGroupById(raw_sender)
+
+                    yield (sender, message)
                 else:
                     print "[*] %s" % OT._VALUES_TO_NAMES[operation.type]
                     print operation
 
                 self.revision = max(operation.revision, self.revision)
 
+    def createContactOrRoomOrGroupByMessage(self, message):
+        if message.toType == ToType.USER:
+            pass
+        elif message.toType == ToType.ROOM:
+            pass
+        elif message.toType == ToType.GROUP:
+            pass
+
     def getLineMessageFromMessage(self, messages=[]):
         """Change Message objects to LineMessage objects
 
